pub enum EvalError {
Show 43 variants
Todo(String),
ListIndexOutOfBounds {
index: usize,
len: usize,
},
TypeMismatch {
id: Identifier,
expected: Type,
found: Type,
},
ArrayElementsDifferentTypes(TypeList),
SymbolNotFound(QualifiedName),
SymbolCannotBeCalled(QualifiedName),
AmbiguousSymbol(QualifiedName, QualifiedNames),
LocalNotFound(Identifier),
PropertyNotFound(Identifier),
NoPropertyId(QualifiedName),
ArgumentCountMismatch {
args: String,
expected: usize,
found: usize,
},
AssertionFailed(String),
ExpectedType {
expected: Type,
found: Type,
},
DiagError(DiagError),
LocalStackEmpty(Identifier),
WrongStackFrame(Identifier, &'static str),
ValueError(ValueError),
UnknownMethod(QualifiedName),
LowerError(LowerError),
UnexpectedNested(&'static str, Identifier),
MissingArguments(IdentifierList),
TooManyArguments(IdentifierList),
IdMatchButNotType(String),
BuiltinError(String),
MultiplicityNotAllowed(IdentifierList),
CannotMixGeometry,
IfConditionIsNotBool {
condition: String,
src_ref: SrcRef,
},
NoInitializationFound {
src_ref: SrcRef,
name: Identifier,
actual_params: String,
possible_params: Vec<String>,
},
AmbiguousInitialization {
src_ref: SrcRef,
name: Identifier,
actual_params: String,
ambiguous_params: Vec<String>,
},
BuildingPlanIncomplete(IdentifierList),
EmptyModelExpression,
WorkbenchInvalidOutput {
kind: WorkbenchKind,
produced: OutputType,
expected: OutputType,
},
ResolveError(ResolveError),
CannotCallOperationWithoutWorkpiece,
NoModelInWorkbench,
ValueAlreadyDefined {
location: SrcRef,
name: Identifier,
value: String,
previous_location: SrcRef,
},
NotAnLValue(Identifier),
SymbolIsPrivate {
what: QualifiedName,
within: QualifiedName,
},
UnusedGlobalSymbol(String),
UnusedLocal(Identifier),
ResolveFailed,
BadRange(i64, i64),
AmbiguousType {
ty: Type,
src_ref: SrcRef,
},
}Expand description
Evaluation error.
Variants
Todo(String)
Can’t find a project file by it’s qualified name.
ListIndexOutOfBounds
List index out of bounds.
TypeMismatch
Parameter type mismatch.
ArrayElementsDifferentTypes(TypeList)
Array elements have different types.
SymbolNotFound(QualifiedName)
Symbol not found.
SymbolCannotBeCalled(QualifiedName)
The symbol cannot be called, e.g. when it is a source file or a module.
AmbiguousSymbol(QualifiedName, QualifiedNames)
Found ambiguous symbols.
LocalNotFound(Identifier)
Local Symbol not found.
PropertyNotFound(Identifier)
A property of a value was not found.
NoPropertyId(QualifiedName)
A property of a value was not found.
ArgumentCountMismatch
Argument count mismatch.
Fields
AssertionFailed(String)
Assertion failed.
ExpectedType
Different type expected.
DiagError(DiagError)
Diagnostic error
LocalStackEmpty(Identifier)
No locals available on stack.
WrongStackFrame(Identifier, &'static str)
Unexpected stack frame type
ValueError(ValueError)
Value Error.
UnknownMethod(QualifiedName)
Unknown method.
LowerError(LowerError)
Parser Error
UnexpectedNested(&'static str, Identifier)
Unexpected element within expression.
MissingArguments(IdentifierList)
Missing arguments
TooManyArguments(IdentifierList)
Missing arguments
IdMatchButNotType(String)
Arguments match by identifier but have incompatible types
BuiltinError(String)
Builtin error
MultiplicityNotAllowed(IdentifierList)
Trying to use multiplicity where it is not allowed
CannotMixGeometry
An error if you try to mix 2d and 3d geometries.
IfConditionIsNotBool
A condition of an if statement is not a boolean
NoInitializationFound
Workbench didn’t find a initialization routine matching the given arguments
AmbiguousInitialization
Workbench didn’t find a initialization routine matching the given arguments
BuildingPlanIncomplete(IdentifierList)
Initializer missed to set a property from plan
EmptyModelExpression
This errors happens if the expression is supposed to produce models but did not.
WorkbenchInvalidOutput
This error happens if the workbench produced a different output type.
ResolveError(ResolveError)
Resolve Error
CannotCallOperationWithoutWorkpiece
Cannot call operation without workpiece, e.g. op().
NoModelInWorkbench
There is no model in this workbench
ValueAlreadyDefined
Assignment failed because value already has been defined before.
Fields
name: IdentifierName of the value
NotAnLValue(Identifier)
Assignment failed because left side is not an l-value
SymbolIsPrivate
Found symbol but it’s not visible to user
UnusedGlobalSymbol(String)
Found unused global symbols.
UnusedLocal(Identifier)
Unused local.
ResolveFailed
Evaluation aborted because of prior resolve errors
BadRange(i64, i64)
Bad range (first > last)
AmbiguousType
Ambiguous types in tuple