pub struct Source {
pub doc: Option<DocBlock>,
pub name: QualifiedName,
pub statements: StatementList,
pub url: Url,
pub source: Hashed<String>,
pub line_offset: u32,
}Expand description
µcad source file
Fields
doc: Option<DocBlock>Documentation.
name: QualifiedNameQualified name of the file if loaded from externals
statements: StatementListRoot code body.
url: UrlName of loaded file.
source: Hashed<String>Source file string with hash
line_offset: u32Line offset
Implementations
Sourceimpl Source
impl Source
Sourcepub fn new(
doc: Option<DocBlock>,
statements: StatementList,
source: Hashed<String>,
url: Url,
) -> Self
pub fn new( doc: Option<DocBlock>, statements: StatementList, source: Hashed<String>, url: Url, ) -> Self
Create new source file from existing source.
pub fn with_line_offset(self, line_offset: u32) -> Self
Sourcepub fn id(&self) -> Identifier
pub fn id(&self) -> Identifier
Return the module name from the file name
Sourcepub fn set_filename(&mut self, path: impl AsRef<Path>)
pub fn set_filename(&mut self, path: impl AsRef<Path>)
Return filename of loaded file or <NO FILE>
Sourcepub fn get_code(&self, src_ref: &SrcRef) -> &str
pub fn get_code(&self, src_ref: &SrcRef) -> &str
get a specific line
line: line number beginning at0
Sourcepub fn set_name(&mut self, name: QualifiedName)
pub fn set_name(&mut self, name: QualifiedName)
Set file name.
Sourcepub fn source_loc_info<'a>(&'a self) -> SourceLocInfo<'a>
pub fn source_loc_info<'a>(&'a self) -> SourceLocInfo<'a>
Get a miette source adapter for the SourceFile
Sourceimpl Source
impl Source
pub fn from_source(source: &Source) -> Result<Rc<Self>, LowerError>
Sourcepub fn load(
path: impl AsRef<Path> + Debug,
) -> Result<Rc<Self>, LowerErrorsWithSource>
pub fn load( path: impl AsRef<Path> + Debug, ) -> Result<Rc<Self>, LowerErrorsWithSource>
Load µcad source file from given path
Sourcepub fn load_with_name(
path: impl AsRef<Path> + Debug,
name: QualifiedName,
) -> (Rc<Self>, Option<LowerErrorsWithSource>)
pub fn load_with_name( path: impl AsRef<Path> + Debug, name: QualifiedName, ) -> (Rc<Self>, Option<LowerErrorsWithSource>)
Load µcad source file from given path
Sourcepub fn load_from_str(
name: Option<&str>,
path: impl AsRef<Path>,
source_str: &str,
) -> Result<Rc<Self>, Vec<LowerError>>
pub fn load_from_str( name: Option<&str>, path: impl AsRef<Path>, source_str: &str, ) -> Result<Rc<Self>, Vec<LowerError>>
Create SourceFile from string
The hash of the result will be of crate::from_str!().
Sourcepub fn name_from_path(path: impl AsRef<Path>) -> QualifiedName
pub fn name_from_path(path: impl AsRef<Path>) -> QualifiedName
Get the source file name from path.
Sourceimpl Source
impl Source
Sourcepub fn symbolize(
&self,
visibility: Visibility,
context: &mut ResolveContext,
) -> ResolveResult<Symbol>
pub fn symbolize( &self, visibility: Visibility, context: &mut ResolveContext, ) -> ResolveResult<Symbol>
Create symbol from definition.