Unit

Enum Unit 

pub enum Unit {
Show 38 variants None, Percent, Meter, Centimeter, Millimeter, Micrometer, Inch, Foot, Yard, Deg, DegS, Grad, Turns, Rad, Gram, Kilogram, Pound, Ounce, Meter2, Centimeter2, Millimeter2, Micrometer2, Inch2, Foot2, Yard2, Meter3, Centimeter3, Millimeter3, Micrometer3, Inch3, Foot3, Yard3, Liter, Centiliter, Milliliter, Microliter, GramPerMeter3, GramPerMillimeter3,
}
Definition of type & scale of numbers.

Variants



None

No unit was given.



Percent

Percents



Meter

Meters



Centimeter

Centimeters



Millimeter

Millimeters



Micrometer

Micrometers



Inch

Inches



Foot

Feet



Yard

Yards



Deg

Degree



DegS

Degree



Grad

Gradient



Turns

Turns



Rad

Radians



Gram

Grams



Kilogram

Kilograms



Pound

Pounds



Ounce

Ounces



Meter2

Square Meters



Centimeter2

Square Centimeters



Millimeter2

Square Millimeters



Micrometer2

Square Micrometers



Inch2

Square Inches



Foot2

Square Foot



Yard2

Square Yard



Meter3

Cubic Meters



Centimeter3

Cubic Centimeters



Millimeter3

Cubic Millimeters



Micrometer3

Cubic Micrometers



Inch3

Cubic Inches



Foot3

Cubic Foot



Yard3

Cubic Yard



Liter

Liters



Centiliter

Centiliter



Milliliter

Milliliter



Microliter

Microliter



GramPerMeter3

Density



GramPerMillimeter3

Density

Implementations

Source

impl Unit

pub fn quantity_type(&self) -> QuantityType

pub fn factor(&self) -> f64

pub fn normalize(self, x: f64) -> f64

Normalize value to base unit.

pub fn denormalize(self, x: f64) -> f64

Denormalize value to unit